@@ -30,7 +30,7 @@ class InstrumentWrapper(param.Parameterized):
         if "software_software" in self.devices.keys():
             self.instrument_selected = "software_software"
         elif len(self.devices.keys()) == 1:
-            self.instrument_selected = self.devices.keys()[0]  # use only available option
+            self.instrument_selected = list(self.devices.keys())[0]  # use only available option
 
     def reload_devices(self, event=None, debug=False):
         ports = find_ports()
